==> haskell-aeson-yaml-1.1.0.1-311-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-K2sJgmZRmeH3wd0QWTLKyV
key:                  aeson-yaml-1.1.0.1-K2sJgmZRmeH3wd0QWTLKyV
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  8695bad960864fe60464628e9236d1be
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-K2sJgmZRmeH3wd0QWTLKyV
depends:
    aeson-2.1.2.1-6ANjbGmrSDg8K6hz3VmYXP base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    unordered-containers-0.2.20-6WajAJaPEOH3f3auRxdjt7
    vector-0.13.2.0-ESntcdl2teUG0zU6GNugJH

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-yaml-1.1.0.1-312-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-yaml
version:              1.1.0.1
visibility:           public
id:                   aeson-yaml-1.1.0.1-AWTPO2qP4Ah39ZCZBLnGOF
key:                  aeson-yaml-1.1.0.1-AWTPO2qP4Ah39ZCZBLnGOF
license:              BSD-3-Clause
copyright:            2019 Clovyr LLC
maintainer:           patrick@clovyr.io
author:               Patrick Nielsen
homepage:             https://github.com/clovyr/aeson-yaml
synopsis:             Output any Aeson value as YAML (pure Haskell library)
description:
    This library exposes functions for encoding any Aeson value as YAML. There
    is also support for encoding multiple values into YAML "documents".

    This library is pure Haskell, and does not depend on C FFI with libyaml. It
    is also licensed under the BSD3 license.

category:             Text, Web, JSON, YAML
abi:                  0f9c4aaac10b52e71725eb4592cbb558
exposed:              True
exposed-modules:      Data.Aeson.Yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-yaml-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-yaml
hs-libraries:         HSaeson-yaml-1.1.0.1-AWTPO2qP4Ah39ZCZBLnGOF
depends:
    aeson-2.1.2.1-JflO2jKMgLf4qHLretO6v3 base-4.17.2.1
    bytestring-0.11.5.3 text-2.0.2
    unordered-containers-0.2.20-Eo1ocpXri5ABLOF81VToPu
    vector-0.13.2.0-ByKMfTK8tTR39fPNQcIOcc

haddock-interfaces:   /usr/share/doc/haskell-aeson-yaml/html/aeson-yaml.haddock
haddock-html:         /usr/share/doc/haskell-aeson-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
